@@ -54,7 +54,7 @@ def E(expr,color = "red"):
       DataRealSymbolList.append([element[0],word])
   #display(DataRealSymbolList)
   D(expr)
-  
+
   if isinstance(expr,sy.core.relational.Equality):
     D(expr.subs(DatosList))
     D(expr.subs(DataRealSymbolList))
@@ -76,7 +76,10 @@ def G(c_componente):#Guardar
     DatosList.append(c_componente)#Si el emento no estaba adentro, simplemente lo agregamos.
   
   #Renderizado Gris
-  D(c_componente,"gray")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
+  if c_componente[1] == None:
+    D(c_componente,"gray")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
+  else:
+    D(c_componente,"red")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
 
 
 #Arreglar
